#
# spec file for package libiio
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver  0
Name:           libiio
Version:        0.17
Release:        lp150.1.2
Summary:        Industrial I/O tools
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://wiki.analog.com/resources/tools-software/linux-software/libiio
Source:         https://github.com/analogdevicesinc/libiio/archive/v%{version}.tar.gz#/libiio-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  libavahi-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  libxml2-devel
BuildRequires:  python3-devel
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}

%description
Library for industrial I/O.

%package -n libiio%{so_ver}
Summary:        Industrial I/O library
Group:          System/Libraries

%description -n libiio%{so_ver}
Library for industrial I/O.

%package devel
Summary:        Industrial I/O library -- development files
Group:          Development/Libraries/C and C++
Requires:       libiio%{so_ver} = %{version}-%{release}
Recommends:     libiio = %{version}-%{release}

%description devel
Library for industrial I/O.

This sub-package contains the development files.

%package python
Summary:        Industrial I/O library -- Python bindings
Group:          System/Libraries

%description python
Library for industrial I/O.

This sub-package contains the Python bindings.

%package daemon
Summary:        Industrial I/O library -- iiod
Group:          System/Libraries

%description daemon
Library for industrial I/O.

This sub-package contains the iiod daemon.

%package usb-udev-rules
Summary:        Industrial I/O library -- iiod
Group:          System/Libraries

%description usb-udev-rules
Library for industrial I/O.

This sub-package contains a udev rule for granting access to IIO targets
using the USB transport/backend.


%prep
%setup -q
sed -i '1s|#!/usr/bin/env python|#!/usr/bin/python3|g' bindings/python/iio.py

%build
%cmake \
  -DPYTHON_EXECUTABLE=%{_bindir}/python3 \
  -DUDEV_RULES_INSTALL_DIR=%{_udevrulesdir} \
  -DWITH_SYSTEMD=1 \
  -DSYSTEMD_UNIT_INSTALL_DIR=%{_unitdir}
%make_jobs

%install
%cmake_install

%check
%ctest

%post -n libiio%{so_ver} -p /sbin/ldconfig
%postun -n libiio%{so_ver} -p /sbin/ldconfig
%pre daemon
%service_add_pre iiod.service

%post daemon
%service_add_post iiod.service

%preun daemon
%service_del_preun iiod.service

%postun daemon
%service_del_postun iiod.service

%files
%license COPYING.txt
%doc README.md
%{_bindir}/iio_adi_xflow_check
%{_bindir}/iio_attr
%{_bindir}/iio_genxml
%{_bindir}/iio_info
%{_bindir}/iio_readdev
%{_bindir}/iio_reg
%{_bindir}/iio_writedev

%files -n libiio%{so_ver}
%{_libdir}/libiio.so.%{so_ver}*

%files -n libiio-devel
%{_includedir}/iio.h
%{_libdir}/libiio.so
%{_libdir}/pkgconfig/libiio.pc

%files python
%{python3_sitelib}/*

%files daemon
%{_sbindir}/iiod
%{_unitdir}/iiod.service

%files usb-udev-rules
%{_udevrulesdir}

%changelog
* Thu Jan 24 2019 mardnh@gmx.de
- Update to version 0.17
  * Revert "sort: when sorting iio_channels, if the index is the
    same, use ID"
- Update to version 0.16
  * fix snprintf warnings from gcc 8
  * channel: Fix #219 get_modifier and get_type seems to work incorrectly
  * sorting: ensure sorting happens after global attributes are added
  * Revert "sort: Move channel attribute sorting to context creation" fix #215
  * cmake: set the CPACK_DEBIAN_PACKAGE_ARCHITECTURE for old versions of Cmake
  * buffer: Fix bug in mask bit tests (continued)
  * IIOD: Fix bug in mask bit tests (continued)
  * add note about triggered buffers in dox source
  * local: pass errors up the stack
  * usb: Increase ctrl pipe timeout
  * usb: add libusb version to context attributes
  * usb: be more verbose when unable to claim an interface
  * Ensure iio_info can find a locally installed libiio.so
  * fix whitespace damage from previous commits
  * sort: when sorting iio_channels, if the index is the same, use ID
  * sort: Move channel attribute sorting to context creation
  * sort: change function names to be more descriptive/accurate
  * Update FIR enable function in ML bindings to not force sample rate ahead of filter write.
  * local: Sort devices, channels and attributes when adding them.
  * Fix FIR load function in ML bindings to actually enable the FIR once loaded.
  * spelling fonction->function
  * Fix bug in mask bit tests
  * cmake: Suppress errors when looking up the git repository path
* Mon Oct  1 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Enable support for USB backend, create usb-udev-rules
- Enable autodiscovery for the network backend using avahi/mDNS/DNS-SD
* Tue May  8 2018 mardnh@gmx.de
- Update to version 0.15
  * network: Add workaround for Microsoft Windows Subsystem for Linux
  * examples/dummy-iiostream: Fix instructions
  * local: Fix low-speed mode
  * appveyor.yml: Add workaround for 32-bit build
  * appveyor.yml: Fix libzip dll name pattern
  * Fix buffer/device mixup in docs
  * Prevent out-of-bounds access in read_each_attr()/iio_channel_attr_read_all()
  * tests/iio_writedev: Add iio_writedev analogous to iio_readdev
  * iio_adi_xflow_check: Avoid accessing device after context destruction
  * Install iiod upstart conf file
  * Install iiod SysVinit script
  * Install iiod.service file
  * Fix typo in CMakeLists.txt
  * iio_readdev: Fix getopt() handling
  * iio_info: Fix getopt() handling
  * iio_genxml: Fix getopt() handling
  * iio_attr: Fix getopt() handling
  * iio_adi_xflow_check: Fix getopt() handling
  * appveyor.yml: Drop the initial core update which updates the package list and
    upgrades all the outdated packages. The conflicts are not handled properly when
    using the --noconfirm option(default values).
  * CMakeLists.txt: Fill in the Windows file information (version, name, copyright, year).
  * appveyor.yml: Install windres for reading Windows resource files (.rc)
  * Added a new variable to iio.Buffer stored in self._ctx, this is reference to a
    Context variable. This reference ensures that the Context outlives the buffer,
    if this is not the case a segmentation violation will occur when destroying the
    buffer.
* Wed Apr  4 2018 tuukka.pasanen@ilmi.fi
- Update to version 0.14
  * network: Fix buffer reuse
  * appveyor.yml: Downgrade llvm and clang packages for the moment
  * Bump to version v0.13
  * network: Fix crash when lots of file descriptors are open
  * Revert "RFC: Fix channel identifier heuristics"
  * local: fix last_dequeued is not invalidated in case of a timeout (blocking)
    or on retry (non-blocking) buffer
  * RFC: Fix channel identifier heuristics
  * appveyor.yml: Copy the README file in the .zip artifact.
  * Sync README and appveyor so the README points to the latest master.
  * appveyor.yml: Change the name of the zip artifact.
  * Create zip.txt
  * network: Adjust switch statment "fall-through" comment position
  * iio_attr: Add support for buffer attribtues
  * iio_info: Add support for buffer attributes
  * iiod: Add support for buffer attributes
  * device: Add support for buffer attributes
  * local: Track buffer attributes
  * iiod: usbd: initialize the SuperSpeed Endpoint Companion descriptors
  * travis-ci: fix typo in matrix
  * CMake: quote arguments for STREQUAL
  * examples/ad9371-iiostream.c: Add AD9371/5 IIO Streaming example
  * local: Track requested and allocated number of blocks independently
  * local: Return error when no blocks could be allocated
  * Cmake: If the version of libserialport isn't 0.1.1; don't fail, just warn, and continue
    building without it. This makes it easier for those (Ubuntu 16 LTS), who are using
    distributions that don't keep up to date.
  * Update channel type and modifier lists
  * iiod: fix crash setting buffers on invalid device
  * appveyor.yml: Move all the MSVC and MinGW builds into a single ZIP artifact.
  * travis-ci: Allow before_deploy to be run twice, which is what happens on a release/tag,
    without erroring
  * travis-ci: Deploy OS-X files on releases
  * appveyor.yml: Create MinGW builds for Windows 32 bit and 64 bit.
* Wed Jan 17 2018 mardnh@gmx.de
- Force usage of python3
* Tue Dec  5 2017 wk@ire.pw.edu.pl
- Update to version 0.11:
  * Lots of bug fixes
  * Add 'ip,ip-addr' context attribute to network contexts
  * Better handling of communication timeouts on Windows
  * IIOD can now stream much faster, up to the link's speed
  * Fix USB backend and IIOD not handling huge buffers
  * Channels are now disabled when a iio_buffer is destroyed
  * Libiio/IIOD can now handle channels that share their index
  * Add 'iio_attr' tool to read/write device/channel attributes
* Mon Jul 24 2017 mardnh@gmx.de
- Update to version 0.10:
  * Lots of bug fixes
  * Add 'ip,ip-addr' context attribute to network contexts
  * Better handling of communication timeouts on Windows
  * IIOD can now stream much faster, up to the link's speed
  * Fix USB backend and IIOD not handling huge buffers
  * Channels are now disabled when a iio_buffer is destroyed
  * Libiio/IIOD can now handle channels that share their index
  * Add 'iio_attr' tool to read/write device/channel attributes
* Tue May 23 2017 stefan.bruens@rwth-aachen.de
- Update to v0.9 - Changelog:
  * Introduced context attributes
  * Add API for querying the list of enabled backends
  * IIOD can now serve over USB (using FunctionFS)
  * Fix occasional buffer drops in IIOD
  * Python bindings are now compatible with Python 3
  * Add support for scanning in Python bindings
  * Fix USB backend on Windows >= 8.1
  * Add auto context creation in iio_readdev/iio_info
  * Lots, lots of bug fixes
- Update to v0.8 - no changelog provided
- drop libiio_systemd.patch, taken from upstream
* Sun Oct 30 2016 afaerber@suse.de
- Initial (v0.7)
